@@ -2,6 +2,7 @@
 # standard library
 import os
 import re
+import sys
 
 TMPDIR = os.getenv('TMPDIR', '/tmp')
 EPS = 1e-8  # a small number
@@ -11,19 +12,20 @@ ANALYSES = ['tlr', 'lr', 'l', 'r', 'ml', 'full', 'nj', 'bionj', 'bionj+', 'lk']
 DNA_ACGT_THRESHOLD = 0.75  # proportion of ACGT in sequence to call it as DNA
 POSINF = float('inf')  # positive infinity
 NEGINF = -POSINF  # negative infinity
-VERSION = '1.0.1'
+PARALLEL_PROFILE = os.getenv('IPYTHON_PROFILE', None)
 PHYML_MEMORY_MULTIPLIER = 1.2  # Add %age wiggle room when calculating Phyml
 # memory requirements on LSF
 PHYML_MEMORY_SPARE = 256  # Allocate extra Mb of memory on LSF jobs
 PHYML_MEMORY_MIN = 512
 PHYML_MEMORY_STANDARD = 4096
-PLL_RANDOM_SEED = int('CA55E77E', 16)
+RANDOM_SEED = int('CA55E77E', 16)
 logo = """
 ═══════════ ╔═╗┬
 ┌┬┐┬─┐┌─┐┌─┐║  │
  │ ├┬┘├┤ ├┤ ╚═╝┴─┘
  ┴ ┴└─└─┘└─┘╭─────
 ┈┈┈┈┈┈┄┄┄┄┄─┤  ╭──
-   V{0:s}   ╰──┤
+            ╰──┤
 ══════════════ ╰──
-""".format(VERSION)
+"""
+ISPY3 = sys.version_info.major>=3
\ No newline at end of file
