@@ -1,5 +1,9 @@
 #!/usr/bin/env python
 from __future__ import print_function, division
+from builtins import zip
+from builtins import str
+from builtins import range
+from builtins import object
 
 # standard library
 import numbers
@@ -10,10 +14,10 @@ import sys
 import numpy as np
 
 # treeCl
-from clustering import Partition
-from tree import Tree
-import errors
-from utils import fileIO, print_and_return
+from .partition import Partition
+from .tree import Tree
+from . import errors
+from .utils import fileIO, print_and_return
 
 
 class Simulator(object):
@@ -34,8 +38,8 @@ class Simulator(object):
             class_list,
             permutations_list,
             nspecies,
-            tmpdir,
-            datatype='protein',
+            subst_model,
+            rate_model,
             master_tree_generator_method='yule',
             master_tree=None,
             class_tree_permuter='nni',
@@ -52,8 +56,7 @@ class Simulator(object):
         # default
         errors.optioncheck(master_tree_generator_method, ['yule', 'coal',
                                                           'rtree', 'custom'])
-        errors.optioncheck(class_tree_permuter, ['nni', 'spr', 'lgt', 'genetree'
-        ])
+        errors.optioncheck(class_tree_permuter, ['nni', 'spr', 'lgt', 'genetree'])
         if master_tree is None and master_tree_generator_method == 'custom':
             raise Exception('No custom tree was specified')
         self.num_classes = len(class_list)
