@@ -10,7 +10,7 @@ from tree_distance import getEuclideanDistance, getGeodesicDistance, getRobinson
     getWeightedRobinsonFouldsDistance
 
 # treeCl
-from utils import setup_progressbar
+from .utils import setup_progressbar
 
 __all__ = ["eucdist", "eucdist_matrix", "geodist", "geodist_matrix", "rfdist", "rfdist_matrix", "wrfdist",
            "wrfdist_matrix"]
@@ -29,7 +29,7 @@ def _equalise_leaf_sets(t1, t2, inplace):
     return pruned1, pruned2
 
 
-def _generic_distance_calc(fn, t1, t2, normalise):
+def _generic_distance_calc(fn, t1, t2, normalise, min_overlap=4):
     """(fn, t1, t2, normalise)
 
     Calculates the distance between trees t1 and t2. Can optionally be normalised to range [0, 1].
@@ -37,6 +37,7 @@ def _generic_distance_calc(fn, t1, t2, normalise):
     some overhead - if the trees are known to have the same leaves, then the underlying distance function [listed below]
     can be called instead, although in these cases the Tree arguments will need to be replaced with Tree.phylotree
     to make sure the appropriate data structure is passed.
+    The distance is taken to be zero if the leaf overlap between the trees is less than `min_overlap`.
     E.g.
         treeCl.treedist.eucdist(t1, t2, False) is the leafset checking equivalent of
         treeCl.treedist.getEuclideanDistance(t1.phylotree, t2.phylotree, False)
@@ -56,16 +57,20 @@ def _generic_distance_calc(fn, t1, t2, normalise):
     :param t1: Tree
     :param t2: Tree
     :param normalise: boolean
+    :param min_overlap: int
     :return: float
     """
     if t1 ^ t2:
-        t1, t2 = _equalise_leaf_sets(t1, t2, False)
-    if len(t1 & t2) < 2:
-        raise AttributeError('Can\'t calculate tree distances when tree overlap is less than two leaves')
+        if len(t1 & t2) < min_overlap:
+            return 0
+            #raise AttributeError('Can\'t calculate tree distances when tree overlap is less than two leaves')
+        else:
+            t1, t2 = _equalise_leaf_sets(t1, t2, False)
+
     return fn(t1.phylotree, t2.phylotree, normalise)
 
 
-def _generic_matrix_calc(fn, trees, normalise):
+def _generic_matrix_calc(fn, trees, normalise, min_overlap=4):
     """(fn, trees, normalise)
 
     Calculates all pairwise distances between trees given in the parameter 'trees'.
@@ -87,6 +92,7 @@ def _generic_matrix_calc(fn, trees, normalise):
 
     :param trees: list or tuple, or some other iterable container type containing Tree objects
     :param normalise: boolean
+    :param min_overlap: int
     :return: numpy.array
     """
     jobs = itertools.combinations(trees, 2)
@@ -94,7 +100,7 @@ def _generic_matrix_calc(fn, trees, normalise):
     pbar = setup_progressbar('Calculating tree distances', 0.5 * len(trees) * (len(trees) - 1))
     pbar.start()
     for i, (t1, t2) in enumerate(jobs):
-        results.append(_generic_distance_calc(fn, t1, t2, normalise))
+        results.append(_generic_distance_calc(fn, t1, t2, normalise, min_overlap))
         pbar.update(i)
     pbar.finish()
     return scipy.spatial.distance.squareform(results)
