@@ -1,5 +1,7 @@
 #!/usr/bin/env python
 from __future__ import print_function
+from builtins import str
+from builtins import range
 import sys
 
 __all__ = ['print_and_return']
